var fs = require('fs');
var crypto = require('crypto');
var console = process.console;
var config = require('./config.js');
var Steam = require('steam');
var SteamWebLogOn = require('steam-weblogon');
var getSteamAPIKey = require('steam-web-api-key');
var SteamTradeOffers = require('steam-tradeoffers');
var SteamCommunity = require('steamcommunity');
var SteamcommunityMobileConfirmations = require('steamcommunity-mobile-confirmations');
var SteamTotp = require('steam-totp');
var redisClient, io, requestify;
module.exports.init = function(redis, ioSocket, requestifyCore) {
    io = ioSocket;
    redisClient = redis.createClient();
    requestify = requestifyCore;
}

var logOnOptions = {
    account_name: config.giveaway.username,
    password: config.giveaway.password,
	two_factor_code: SteamTotp.generateAuthCode(config.giveaway.secret)
};
function gen() { 
code = SteamTotp.generateAuthCode(config.giveaway.secret); 
GiveawayLogger('Код Авторизации : ' + code); 
return code; 
} 
setInterval(gen,60000); 
function GiveawayLogger(log) {
    console.tag('РОЗЫГРЫШ').log(log);
}
var steamClient = new Steam.SteamClient();
var steamUser = new Steam.SteamUser(steamClient);
var steamFriends = new Steam.SteamFriends(steamClient);
var steamWebLogOn = new SteamWebLogOn(steamClient, steamUser);
var offers = new SteamTradeOffers();

// Generation Device_ID
var hash = require('crypto').createHash('sha1');
hash.update(Math.random().toString());
hash = hash.digest('hex');
var device_id = 'android:' + hash;
var acceptInterval;

var checkingOffers = [],
    WebCookies = [],
    WebSession = false,
    globalSession;


const redisChannels = {
    additems: 'additemsgiveaway',
    senditems: 'senditemsgiveaway',
    endgiveaway: 'endgiveaway'
}

steamClient.connect();
steamClient.on('debug', GiveawayLogger);
steamClient.on('connected', function() {
    steamUser.logOn(logOnOptions);
});

steamClient.on('logOnResponse', function (logonResp) {
    if (logonResp.eresult === Steam.EResult.OK) {
        GiveawayLogger('Залогинился!');
        steamFriends.setPersonaState(Steam.EPersonaState.LookingToTrade);

        steamWebLogOn.webLogOn(function (sessionID, newCookie) {
            getSteamAPIKey({
                sessionID: sessionID,
                webCookie: newCookie
            }, function (err, APIKey) {
                offers.setup({
                    sessionID: sessionID,
                    webCookie: newCookie,
                    APIKey: APIKey
                }, function (err) {
                    WebSession = true;
                    globalSession = sessionID;
                    WebCookies = newCookie;
                    redisClient.lrange(redisChannels.tradeoffersList, 0, -1, function (err, offers) {
                        offers.forEach(function (offer) {
                            checkingOffers.push(offer);
                        });
                        handleOffers();
                    });
                    GiveawayLogger('Настройка трейдов!');
                });

            });
        });
    }
});

function reWebLogon() {
    steamWebLogOn.webLogOn(function (sessionID, newCookie) {
        getSteamAPIKey({
            sessionID: sessionID,
            webCookie: newCookie
        }, function (err, APIKey) {
            offers.setup({
                sessionID: sessionID,
                webCookie: newCookie,
                APIKey: APIKey
            }, function (err) {
                WebSession = true;
                globalSession = sessionID;
                WebCookies = newCookie;
                GiveawayLogger('WebSession Reloaded!');
            });
        });
    });
}

	

steamClient.on('servers', function(servers) {
    fs.writeFile('servers', JSON.stringify(servers));
});


function handleOffers() {
    offers.getOffers({
        get_received_offers: 1,
        active_only: 1
    }, function (error, body) {
        if (
            body
            && body.response
            && body.response.trade_offers_received
        ) {
            body.response.trade_offers_received.forEach(function (offer) {
                if (offer.trade_offer_state == 2) {
                    if (is_checkingOfferExists(offer.tradeofferid)) return;

                    if (offer.items_to_give != null && config.admins.indexOf(offer.steamid_other) != -1) {
                        console.tag('РОЗЫГРЫШ', 'Трейд').log('Трейд #' + offer.tradeofferid + ' От: АДМИНА ' + offer.steamid_other);
                        offers.acceptOffer({tradeOfferId: offer.tradeofferid});
                        AcceptMobileOffer();
                        return;
                    }

                    if (offer.items_to_give != null) {
                        offers.declineOffer({tradeOfferId: offer.tradeofferid});
                        return;
                    }
                    offers.getTradeHoldDuration({tradeOfferId: offer.tradeofferid}, function (err, response) {
                        if (err) {
                            GiveawayLogger('Отклонение. Нету ESCROW: ' + err);
                            offers.declineOffer({tradeOfferId: offer.tradeofferid});
                            GiveawayLogger('Отклонение. Нету ESCROW: ' + offer.tradeofferid);
                            return;
                        } else if (response.their != 0) {
                            GiveawayLogger('response.their: ' + response.their);
                            offers.declineOffer({tradeOfferId: offer.tradeofferid});
                            GiveawayLogger('Отклонение. Нету ESCROW: ' + offer.tradeofferid);
                            return;
                        }
                    });

					 if ( offer.items_to_receive != null && offer.items_to_give == null) {
                        console.tag('РОЗЫГРЫШ', 'Трейд').log('Трейд #' + offer.tradeofferid + ' От: АДМИНА ' + offer.steamid_other);
                        offers.acceptOffer({
                            tradeOfferId: offer.tradeofferid
                        }, function(error, traderesponse) {
                            if(!error) {
                                if ('undefined' != typeof traderesponse.tradeid) {
                                    offers.getItems({
                                        tradeId: traderesponse.tradeid
                                    }, function (error, recieved_items) {
                                        if (!error) {
                                            var itemsForParse = [], ItemsForGiveaway = [], i = 0;
                                            recieved_items.forEach(function(item){
                                                itemsForParse[i++] = item.id;
                                            })
                                            offers.loadMyInventory({appId: 730, contextId: 2, language: 'russian'}, function(error, botItems){
                                                if(!error){
                                                    i = 0;
                                                    botItems.forEach(function(item){
                                                        if(itemsForParse.indexOf(item.id) != -1){
                                                            var rarity = '', type = '';
                                                            var arr = item.type.split(',');
                                                            if (arr.length == 2) rarity = arr[1].trim();
                                                            if (arr.length == 3) rarity = arr[2].trim();
                                                            if (arr.length && arr[0] == 'Нож') rarity = 'Тайное';
                                                            if (arr.length) type = arr[0];
                                                            var quality = item.market_name.match(/\(([^()]*)\)/);
                                                           if(quality != null && quality.length == 2) {
                                                            quality = quality[1];
                                                            } else {
                                                            quality = "    ";
                                                                } 
                                                            ItemsForGiveaway[i++] = {
                                                                inventoryId: item.id,
                                                                classid: item.classid,
                                                                name: item.name,
                                                                market_hash_name: item.market_hash_name,
                                                                rarity: rarity,
                                                                quality: quality,
                                                                type: type
                                                            }
                                                        }
                                                    });
                                                }
                                                redisClient.rpush(redisChannels.additems, JSON.stringify(ItemsForGiveaway));
                                                return;
                                            });
                                        }
                                        return;
                                    });
                                }
                            }
                            return;
                        });
                    }
                }
            });
        }
    });
}

steamUser.on('tradeOffers', function(number) {
    if (number > 0) {
        handleOffers();
    }
});
steamFriends.on('friendMsg', function(steamID, message, type) { 
if (WebSession){ 
if (config.admins.indexOf(steamID) == -1) return; 
if (message.indexOf("/update") == 0) { 
steamFriends.sendMessage(steamID, "Розыгрыш обновляется"); 
MyInvToSite(); 
} 
} 
}); 
var MyInvToSite = function() {
	console.tag('Магазин').log('Обновляем инвентарь и список предметов на сайте');
	try {
		var ItemsForGiveaway = [], i = 0;
		offers.loadMyInventory({
				appId: 730,
				contextId: 2,
				language: 'russian'
			}, function (error, botItems) {
				if (!error) {
					i = 0;
						botItems.forEach(function (item) {
							if (item.tradable) {
								var rarity = '', type = '';
								var arr = item.type.split(',');
								if (arr.length == 2) rarity = arr[1].trim();
								if (arr.length == 3) rarity = arr[2].trim();
								if (arr.length && arr[0] == 'Нож') rarity = 'Тайное';
								if (arr.length) type = arr[0];
								var quality = item.market_name.match(/\(([^()]*)\)/);
								if (quality != null && quality.length == 2) quality = quality[1];
								 ItemsForGiveaway[i++] = {
                                                                inventoryId: item.id,
                                                                classid: item.classid,
                                                                name: item.name,
                                                                market_hash_name: item.market_hash_name,
                                                                rarity: rarity,
                                                                quality: quality,
                                                                type: type
                                                            }
							}
						});
				}
				redisClient.rpush(redisChannels.additems, JSON.stringify(ItemsForGiveaway));
				return;
			});
	} catch (ex) {
		console.tag('РОЗЫГРЫШ').error('Ошибка обновления');
		sendProcceed = false;
	}
};
var checkArrGlobal = [];

var sendTradeOfferGiveaway = function (appId, partnerSteamId, accessToken, sendItems, message, game, offerJson) {
    try {
        offers.loadMyInventory({
            appId: appId,
            contextId: 2
        }, function (err, items) {
            if (err) {
                console.log(err);
                sendProcceedGiveaway = false;
                return;
            }
            var itemsFromMe = [],
                checkArr = [],
                num = 0;
            var i = 0;
            for (var i = 0; i < sendItems.length; i++) {
                for (var j = 0; j < items.length; j++) {
                    if (items[j].tradable && (items[j].classid == sendItems[i])) {
                        if ((checkArr.indexOf(items[j].id) == -1) && (checkArrGlobal.indexOf(items[j].id) == -1)) {
                            checkArr[i] = items[j].id;
                            itemsFromMe[num] = {
                                appid: 730,
                                contextid: 2,
                                amount: items[j].amount,
                                assetid: items[j].id
                            };
                            num++;
                            break;
                        }
                    }
                }
            }
            if (num > 0) {
                offers.makeOffer({
                    partnerSteamId: partnerSteamId,
                    accessToken: accessToken,
                    itemsFromMe: itemsFromMe,
                    itemsFromThem: [],
                    message: 'Поздравляем с победой в розыгрыше на сайте ' + config.nameSite + ''
                }, function (err, response) {
                    if (err) {
                        console.tag('РОЗЫГРЫШ', 'Отправка выигрыша').error('Ошибка отправки выигрыша:' + err.message);
                        getErrorCode(err.message, function (errCode) {
                            if (errCode == 15 || errCode == 25 || err.message.indexOf('Ошибка отправки вашего трейда. Попробуйте позже!')) {
                                redisClient.lrem(redisChannels.sendOffersListGiveaway, 0, offerJson, function (err, data) {
                                    setPrizeStatus(game, 2);
                                    sendProcceedGiveaway = false;
                                });
                                sendProcceedGiveaway = false;
                            }
                            sendProcceedGiveaway = false;
                        });
                        return;
                    }
                    checkArrGlobal = checkArrGlobal.concat(checkArr);
                    redisClient.lrem(redisChannels.sendOffersListGiveaway, 0, offerJson, function (err, data) {
                        setPrizeStatus(game, 1);
                        sendProcceedGiveaway = false;
                    });
                    console.tag('РОЗЫГРЫШ', 'Отправка выигрыша').log('Трейд #' + response.tradeofferid + ' отправлен!');
                    AcceptMobileOffer();
                });
            } else {
                console.tag('РОЗЫГРЫШ', 'Отправка выигрыша').log('Вещи не найдены!');
                redisClient.lrem(redisChannels.sendOffersListGiveaway, 0, offerJson, function (err, data) {
                    setPrizeStatus(game, 2);
                    sendProcceedGiveaway = false;
                });
            }
        });

    } catch (ex) {
        console.tag('РОЗЫГРЫШ').error('Ошибка отправки выигрыша');
        setGiveawayStatus(game, 2);
        sendProcceedGiveaway = false;
    }
};
var setGiveawayStatus = function (game, status) {
    requestify.post('http://' + config.domain + '/api/giveaway/setGiveawayStatus', {
        secretKey: config.secretKey,
        game: game,
        status: status
    })
        .then(function (response) {

        }, function (response) {
            console.tag('РОЗЫГРЫШ').log('Ошибка с статусом giveaway. Перепробываем...');
            setTimeout(function () {setGiveawayStatus()}, 1000);
        });
}
var addItems = function(){
    requestify.post('http://'+config.domain+'/api/giveaway/addItems', {
        secretKey: config.secretKey
    })
        .then(function(response) {
            var answer = JSON.parse(response.body);
            if(answer.success){
                additemsProcced = false;
            }
        },function(response){
            console.tag('giveaway').error('Something wrong with newItems. Retry...');
            //setTimeout(function(){addItems()}, 1000);
        });
}
var setPrizeStatus = function (game, status) {
    requestify.post('http://' + config.domain + '/api/giveaway/setPrizeStatus', {
        secretKey: config.secretKey,
        game: game,
        status: status
    })
        .then(function (response) {

        }, function (response) {
            console.tag('РОЗЫГРЫШ').log('Ошибка с статусом приза. Перепробываем...');
            setTimeout(function () {
                setPrizeStatus()
            }, 1000);
        });
}

var is_checkingOfferExists = function (tradeofferid) {
    for (var i = 0, len = checkingOffers.length; i < len; ++i) {
        var offer = checkingOffers[i];
        if (offer == tradeofferid) {
            return true;
            break;
        }
    }
    return false;
}

function AcceptMobileOffer() {
    // Информация для мобильных подтверждений
    var steamcommunityMobileConfirmations = new SteamcommunityMobileConfirmations(
        {
            steamid: config.giveaway.steamid,
            identity_secret: config.giveaway.identity_secret,
            device_id: device_id,
            webCookie: WebCookies,
        });

    steamcommunityMobileConfirmations.FetchConfirmations((function (err, confirmations) {
        if (err) {
            console.log(err);
            reWebLogon();
            return;
        }
        console.tag('РОЗЫГРЫШ', 'Мобильное подтверждение').log('Трейдов в ожидании: ' + confirmations.length);
        if (!confirmations.length) {
            return;
        }
        steamcommunityMobileConfirmations.AcceptConfirmation(confirmations[0], (function (err, result) {
            if (err) {
                console.log(err);
                reWebLogon();
                return;
            }
            clearInterval(acceptInterval);
            console.tag('РОЗЫГРЫШ', 'Мобильное подтверждение').log('Результат: ' + result);
        }).bind(this));
    }).bind(this));
}

var queueProceed = function () {
	redisClient.llen(redisChannels.additems, function(err, length) {
        if (length > 0 && !additemsProcced) {
            console.tag('SteamBotBonus','Queues').info('New items to giveaway:' + length);
            additemsProcced = true;
            addItems();
        }
    });
	redisClient.llen(redisChannels.endgiveaway, function (err, length) {
        if (length > 0 && !sendProcceedGiveaway && WebSession) {
            console.tag('БОТ', 'GIVEAWAY').info('Конец розыгрыша');
            redisClient.lindex(redisChannels.endgiveaway, 0, function (err, offerJson) {
                redisClient.lrem(redisChannels.endgiveaway, 0, offerJson, function (err, data) {
                    io.sockets.emit('endgiveaway', offerJson);
                });
            });
        }
    });
    redisClient.llen(redisChannels.senditems, function (err, length) {
        if (length > 0 && !sendProcceedGiveaway && WebSession) {
            console.tag('БОТ', 'Проверка').info('Отправка трейда победителю розыгрыша:' + length);
            sendProcceedGiveaway = true;
            redisClient.lindex(redisChannels.senditems, 0, function (err, offerJson) {
                offer = JSON.parse(offerJson);
                sendoffer = [];
                offer.items.forEach(function(it, key, array) {
                    sendoffer.push(it.classid);
                });
                sendTradeOfferGiveaway(offer.appId, offer.steamid, offer.accessToken, sendoffer, '', offer.game, offerJson);
            });
        }
    });
}
var additemsProcced = false;    
var sendProcceedGiveaway = false;

setInterval(queueProceed, 1500);

module.exports.handleOffers = handleOffers;


function getErrorCode(err, callback) {
    var errCode = 0;
    var match = err.match(/\(([^()]*)\)/);
    if (match != null && match.length == 2) errCode = match[1];
    callback(errCode);
}

