var fs = require('fs');
var crypto = require('crypto');
var console = process.console;
var config = require('./config.js');
var Steam = require('steam');
var SteamWebLogOn = require('steam-weblogon');
var getSteamAPIKey = require('steam-web-api-key');
var SteamTradeOffers = require('steam-tradeoffers');
var SteamCommunity = require('steamcommunity');
var SteamcommunityMobileConfirmations = require('steamcommunity-mobile-confirmations');
var SteamTotp = require('steam-totp');
var redisClient, requestify;


module.exports.init = function (redis, requestifyCore) {
    redisClient = redis.createClient();
    requestify = requestifyCore;
} 

var details = { 
account_name: config.shop.username, 
password: config.shop.password, 
two_factor_code: generatekey(config.shop.shared_secret) 
}; 

var steamClient = new Steam.SteamClient(); 
var steamUser = new Steam.SteamUser(steamClient); 
var steamFriends = new Steam.SteamFriends(steamClient); 
var steamWebLogOn = new SteamWebLogOn(steamClient, steamUser); 
var offers = new SteamTradeOffers(); 

// Generation Device_ID 
var hash = require('crypto').createHash('sha1'); 
hash.update(Math.random().toString()); 
hash = hash.digest('hex'); 
var device_id = 'android:' + hash; 

var checkingOffers = [], 
WebCookies = [], 
WebSession = false, 
globalSession; 

const redisChannels = { 
itemsToSale: 'items.to.sale', 
itemsToCheck: 'items.to.check', 
itemsToGive: 'items.to.give', 
offersToCheck: 'offers.to.check', 
updateShop: 'updateShop' 
} 

function siteShopLogger(log) { 
console.tag('Магазин').log(log); 
} 

function generatekey(secret) { 
code = SteamTotp.generateAuthCode(secret); 
siteShopLogger('Код Авторизации : ' + code); 
return code; 
} 
function gen() { 
code = SteamTotp.generateAuthCode(config.shop.shared_secret); 
siteShopLogger('Код Авторизации : ' + code); 
return code; 
} 
setInterval(gen,60000); 
steamClient.connect(); 
steamClient.on('debug', siteShopLogger); 
steamClient.on('connected', function () { 
steamUser.logOn(details); 
}); 

steamFriends.on('friendMsg', function(steamID, message, type) { 
if (WebSession){ 
if (config.admins.indexOf(steamID) == -1) return; 
if (message.indexOf("/update") == 0) { 
steamFriends.sendMessage(steamID, "Магазин обновляется"); 
MyInvToSite(); 
} 
} 
}); 

steamClient.on('logOnResponse', function (logonResp) { 
if (logonResp.eresult === Steam.EResult.OK) { 
siteShopLogger('Вход выполнен!'); 
steamFriends.setPersonaState(Steam.EPersonaState.Online); 

steamWebLogOn.webLogOn(function (sessionID, newCookie) { 
getSteamAPIKey({ 
sessionID: sessionID, 
webCookie: newCookie 
}, function (err, APIKey) { 
offers.setup({ 
sessionID: sessionID, 
webCookie: newCookie, 
APIKey: APIKey 
}, function (err) { 
WebSession = true; 
globalSession = sessionID; 
WebCookies = newCookie; 
siteShopLogger('Обмены доступны!'); 
handleOffers(); 
}); 

}); 
}); 
} 
}); 



steamClient.on('servers', function (servers) { 
fs.writeFile('servers', JSON.stringify(servers)); 
}); 

function handleOffers() { 
offers.getOffers({ 
get_received_offers: 1, 
active_only: 1 
}, function (error, body) { 
if (body && body.response && body.response.trade_offers_received) { 
body.response.trade_offers_received.forEach(function (offer) { 
if (offer.trade_offer_state == 2) { 
if ((config.admins.indexOf(offer.steamid_other) != -1) || (offer.items_to_give == null && offer.items_to_receive != null)) { 
siteShopLogger('Принимаем обмен #' + offer.tradeofferid + ' от: ' + offer.steamid_other ); 

offers.getTradeHoldDuration({ 
tradeOfferId:
offer.tradeofferid 
}, function(err, response) { 
if (err) { 
siteShopLogger('Ошибка проврки на задержку: ' + err); 
offers.declineOffer({ 
tradeOfferId: offer.tradeofferid 
}); 
siteShopLogger('Трейд отменен из за ошибки: ' + offer.tradeofferid); 
return; 
} else if (response.their != 0) { 
siteShopLogger('response.their: ' + response.their); 
offers.declineOffer({ 
tradeOfferId: offer.tradeofferid 
}); 
siteShopLogger('Трейд отменен из за задержки: ' + offer.tradeofferid); 
return; 
} 
}); 

offers.acceptOffer({ 
tradeOfferId: offer.tradeofferid 
}, function (error, traderesponse) { 
if (!error) { 
if ('undefined' != typeof traderesponse.tradeid) { 
offers.getItems({ 
tradeId: traderesponse.tradeid 
}, function (error, recieved_items) { 
if (!error) { 
var itemsForParse = [], itemsForSale = [], i = 0; 
recieved_items.forEach(function (item) { 
itemsForParse[i++] = item.id; 
}) 
offers.loadMyInventory({ 
appId: 730, 
contextId: 2, 
language: 'russian' 
}, function (error, botItems) { 
if (!error) { 
i = 0; 
botItems.forEach(function (item) { 
if (itemsForParse.indexOf(item.id) != -1) { 
var rarity = '', type = ''; 
var arr = item.type.split(','); 
if (arr.length == 2) rarity = arr[1].trim(); 
if (arr.length == 3) rarity = arr[2].trim(); 
if (arr.length && arr[0] == 'Нож') rarity = 'Тайное'; 
if (arr.length) type = arr[0]; 
var quality = item.market_name.match(/\(([^()]*)\)/); 
if (quality != null && quality.length == 2) quality = quality[1]; 
itemsForSale[i++] = { 
depositorid: offer.steamid_other, 
inventoryId: item.id, 
classid: item.classid, 
name: item.name, 
market_hash_name: item.market_hash_name, 
rarity: rarity, 
quality: quality, 
type: type 
} 
} 
}); 
} 
redisClient.rpush(redisChannels.itemsToSale, JSON.stringify(itemsForSale)); 
return; 
}); 
} 
return; 
}); 
} 
} else { 
siteShopLogger('С Ошибкой: '+ error); 
//reWebLogonShop(); 
setTimeout(handleOffers,20000); 
} 
return; 
}); 
} else { 
offers.declineOffer({tradeOfferId: offer.tradeofferid}); 
} 
return; 
} 
}); 
} 
}); 
} 

steamUser.on('tradeOffers', function (number) { 
console.log('Предложений обмена: ' + number); 
if (number > 0) { 
handleOffers(); 
} 
}); 

var sendTradeOffer = function(offerJson) { 
var offer = JSON.parse(offerJson); 
console.log('Отправляем обмен: ' + offer.steamid); 
try { 
offers.loadMyInventory({ 
appId: 730, 
contextId: 2 
}, function(err, items) { 
if (err) { 
console.log(err); 
sendProcceed = false; 
return; 
} 
var itemsFromMe = [], 
checkArr = [], 
num = 0; 
var i = 0; 
//console.tag('Магазин', 'Обмены').log('Предметы :' + JSON.stringify(offer.items)); 
for (var i = 0; i < offer.items.length; i++) { 
for (var j = 0; j < items.length; j++) { 
if (items[j].tradable && (items[j].id == offer.items[i])) { 
if (checkArr.indexOf(items[j].id) == -1) { 
checkArr[i] = items[j].id; 
itemsFromMe[num] = { 
appid: 730, 
contextid: 2, 
amount: items[j].amount, 
assetid: items[j].id 
}; 
num++; 
break; 
} 
} 
} 
} 
if (num > 0) { 
offers.makeOffer({ 
partnerSteamId: offer.steamid,
accessToken: offer.accessToken, 
itemsFromMe: itemsFromMe, 
itemsFromThem: [], 
message: 'Спасибо за покупку на сайте ' + config.nameSite 
}, function(err, response) { 
if (err) { 
console.log('Err: ' + err); 
getErrorCode(err.message, function (errCode) { 
if (errCode == 15 || errCode == 25 || err.message.indexOf('an error sending your trade offer. Please try again later.')) { 
redisClient.lrem(redisChannels.itemsToGive, 0, offerJson, function (err, data) { 
sendProcceed = false; 
}); 
sendProcceed = false; 
handleOffers(); 
} 
for (var i = 0; i < offer.items.length; i++) { 
setItemStatus(offer.items[i], 4); 
} 
sendProcceed = false; 
}); 
sendProcceed = false; 
//reWebLogonShop(); 
} else if (response) { 
redisClient.lrem(redisChannels.itemsToGive, 0, offerJson, function (err, data) { 
sendProcceed = false; 
for (var i = 0; i < offer.items.length; i++) { 
setItemStatus(offer.items[i], 3); 
} 
console.tag('Магазин', 'Обмены').log('Трейд #' + response.tradeofferid + ' Отправлен!'); 
redisClient.rpush(redisChannels.offersToCheck, response.tradeofferid); 
}); 
} 
}); 
} else { 
console.tag('Магазин', 'Обмены').log('Предметы не найдены!'); 
for (var i = 0; i < offer.items.length; i++) { 
setItemStatus(offer.items[i], 4); 
} 
redisClient.lrem(redisChannels.itemsToGive, 0, offerJson, function (err, data) { 
sendProcceed = false; 
}); 
} 
}); 

} catch (ex) { 
console.tag('Магазин').error('Ошибка отправки предмета'); 
sendProcceed = false; 
//reWebLogonShop(); 
} 
}; 

var MyInvToSite = function() { 
console.tag('Магазин').log('Обновляем инвентарь и список предметов на сайте'); 
if (WebSession){ 
try { 
var itemsForCheck = [], i = 0; 
offers.loadMyInventory({ 
appId: 730, 
contextId: 2, 
language: 'russian' 
}, function (error, botItems) { 
if (!error) { 
i = 0; 
botItems.forEach(function (item) { 
if (item.tradable) { 
var rarity = '', type = ''; 
var arr = item.type.split(','); 
if (arr.length == 2) rarity = arr[1].trim(); 
if (arr.length == 3) rarity = arr[2].trim(); 
if (arr.length && arr[0] == 'Нож') rarity = 'Тайное'; 
if (arr.length) type = arr[0]; 
var quality = item.market_name.match(/\(([^()]*)\)/); 
if (quality != null && quality.length == 2) quality = quality[1]; 
itemsForCheck[i++] = { 
inventoryId: item.id, 
classid: item.classid, 
name: item.name, 
market_hash_name: item.market_hash_name, 
rarity: rarity, 
quality: quality, 
type: type 
} 
} 
}); 
} 
redisClient.rpush(redisChannels.itemsToCheck, JSON.stringify(itemsForCheck)); 
return; 
}); 
} catch (ex) { 
console.tag('Магазин').error('Ошибка обновления'); 
sendProcceed = false; 
} 
} else { 
setTimeout(MyInvToSite,5000); 
} 
}; 

function AcceptMobileOffer() { 
if(WebSession){ 
// Информация для мобильных подтверждений 
var steamcommunityMobileConfirmations = new SteamcommunityMobileConfirmations({ 
steamid: config.shop.steamid, 
identity_secret: config.shop.identity_secret, 
device_id: device_id, 
webCookie: WebCookies, 
}); 

steamcommunityMobileConfirmations.FetchConfirmations((function (err, confirmations) { 
if (err) { 
console.log(err); 
//reWebLogonShop(); 
return; 
} 
if (!confirmations.length) { 
return; 
} else { 
console.tag('Магазин', 'Аутентификатор').log('Ожидает подтверждения: ' + confirmations.length); 
steamcommunityMobileConfirmations.AcceptConfirmation(confirmations[0], (function (err, result) { 
if (err) { 
console.log(err); 
//reWebLogonShop(); 
return; 
} 
console.tag('Магазин', 'Аутентификатор').log('Результат: ' + result);
}).bind(this)); 
} 
}).bind(this)); 
} 
} 

var setItemStatus = function (item, status) { 
requestify.post('http://' + config.domain + '/api/shop/setItemStatus', { 
secretKey: config.secretKey, 
id: item, 
status: status 
}) 
.then(function (response) { 
}, function (response) { 
console.tag('Магазин').error('Something wrong with setItemStatus. Retry...'); 
setTimeout(function () { 
setItemStatus() 
}, 5000); 
}); 
} 

var addNewItems = function () { 
requestify.post('http://' + config.domain + '/api/shop/newItems', { 
secretKey: config.secretKey 
}) 
.then(function (response) { 
var answer = JSON.parse(response.body); 
if (answer.success) { 
console.tag('Магазин').error('Предметы добавлены на сайт !'); 
itemsToSaleProcced = false; 
} 
else { 
console.tag('Магазин').error(answer); 
} 
}, function (response) { 
console.tag('Магазин').error('Something wrong with newItems. Retry...'); 
setTimeout(function () { 
addNewItems() 
}, 5000); 
}); 

} 

var addCheckItems = function () { 
requestify.post('http://' + config.domain + '/api/shop/checkShop', { 
secretKey: config.secretKey 
}) 
.then(function (response) { 
var answer = JSON.parse(response.body); 
if (answer.success) { 
console.tag('Магазин').error('Проверка завершена успешно!'); 
itemsToCheckProcced = false; 
} 
else { 
console.tag('Магазин').error(answer); 
} 
}, function (response) { 
console.tag('Магазин').error('Something wrong with check. Retry...'); 
/*setTimeout(function () { 
addCheckItems() 
}, 1000);*/ 
}); 
} 

var checkOfferForExpired = function (offer) { 
offers.getOffer({tradeOfferId: offer}, function (err, body) { 
if (body.response.offer) { 
var offerCheck = body.response.offer; 
if (offerCheck.trade_offer_state == 2) { 
var timeCheck = Math.floor(Date.now() / 1000) - offerCheck.time_created; 
console.log(timeCheck); 
if (timeCheck >= config.shop.timeForCancelOffer) { 
offers.cancelOffer({tradeOfferId: offer}, function (err, response) { 
if (!err) { 
redisClient.lrem(redisChannels.offersToCheck, 0, offer, function (err, data) { 
siteShopLogger('Offer #' + offer + ' was expired!'); 
checkProcceed = false; 
}); 
} else { 
checkProcceed = false; 
} 
}); 
for (var i = 0; i < offerCheck.items_to_give.length; i++) { 
setItemStatus(offerCheck.items_to_give[i].assetid, 0); 
} 
} else { 
checkProcceed = false; 
} 
return; 
} else if (offerCheck.trade_offer_state == 3 || offerCheck.trade_offer_state == 7) { 
redisClient.lrem(redisChannels.offersToCheck, 0, offer, function (err, data) { 
checkProcceed = false; 
}); 
} else { 
redisClient.lrem(redisChannels.offersToCheck, 0, offer, function (err, data) { 
checkProcceed = false; 
}); 
checkProcceed = false; 
} 
} else { 
checkProcceed = false; 
} 
}) 
} 

var queueProceed = function () { 
redisClient.llen(redisChannels.itemsToSale, function (err, length) { 
if (length > 0 && !itemsToSaleProcced) { 
console.tag('Магазин', 'Ожидание').info('New items to sale:' + length); 
itemsToSaleProcced = true; 
addNewItems(); 
} 
}); 
redisClient.llen(redisChannels.itemsToCheck, function (err, length) { 
if (length > 0 && !itemsToCheckProcced) { 
console.tag('Магазин', 'Ожидание').info('New items to check:' + length); 
itemsToCheckProcced = true; 
addCheckItems(); 
} 
}); 
redisClient.llen(redisChannels.itemsToGive, function (err, length) { 
if (length > 0 && !sendProcceed && WebSession) { 
console.tag('Магазин', 'Ожидание').info('Send items:' + length); 
sendProcceed = true; 
redisClient.lindex(redisChannels.itemsToGive, 0, function (err, offerJson) { 
sendTradeOffer(offerJson); 
}); 
} 
}); 
redisClient.llen(redisChannels.offersToCheck, function (err, length) { 
if (length > 0 && !checkProcceed && WebSession) { 
console.tag('Магазин', 'Ожидание').info('Check Offers:' + length); 
checkProcceed = true; 
redisClient.lindex(redisChannels.offersToCheck, 0, function
(err, offer) { 
checkOfferForExpired(offer); 
}); 
} 
}); 
redisClient.llen(redisChannels.updateShop, function (err, length) { 
if (length > 0 && WebSession) { 
redisClient.lindex(redisChannels.updateShop, 0, function (err, offer) { 
redisClient.lrem(redisChannels.updateShop, 0, offer, function (err, data) { 
MyInvToSite(); 
}); 
}); 
} 
}); 
} 

var itemsToSaleProcced = false; 
var itemsToCheckProcced = false; 
var sendProcceed = false; 
var checkProcceed = false; 
setInterval(queueProceed, 10000); 
setInterval(AcceptMobileOffer, 20000); 
function getErrorCode(err, callback) { 
var errCode = 0; 
var match = err.match(/\(([^()]*)\)/); 
if (match != null && match.length == 2) errCode = match[1]; 
callback(errCode); 
}